@@ -414,6 +414,15 @@ class Model:
             for style in self.styles:
                 if style.row > sizetable[0]:
                     style.row = style.row + sizetable[1]
+            for row_height in self.rows_height:
+                if row_height.row > sizetable[0]:
+                    row_height.row = row_height.row + sizetable[1]
+        rows_height = self.rows_height
+        for sizetable in sizetables:
+            for row_height in rows_height:
+                 if row_height.row == sizetable[0]:
+                     for n in range(sizetable[1]-1):
+                         self.__rows_height.append(Variable(row_height.name+n+1,row_height.row+n+1,row_height.column,row_height.value))
         styles = self.styles
         for sizetable in sizetables:
             for style in styles:
